@@ -767,6 +767,25 @@ class Sequence(Generic[T], Iterable[T]):
                 return True
         return False
     
+    @overload
+    def count(self) -> int:
+        """
+         Returns the number of elements in the Sequence that satisfy the specified [predicate] function.
+
+         Example 1:
+        >>> lst = [1, 2, 3]
+        >>> it(lst).count()
+        3
+        >>> it(lst).count(lambda x: x > 0)
+        3
+        >>> it(lst).count(lambda x: x > 2)
+        1
+
+        """
+        ...
+    @overload
+    def count(self, predicate: Callable[[T], bool]) -> int:
+        ...
     def count(self, predicate: Optional[Callable[[T], bool]] = None) -> int:
         """
          Returns the number of elements in the Sequence that satisfy the specified [predicate] function.
@@ -1204,8 +1223,20 @@ class Sequence(Generic[T], Iterable[T]):
         b
         c
         """
-        for i in self:
-            action(i)
+        self.on_each(action)
+    
+    def parallel_foreach(self, action: Callable[[T], None]) -> None:
+        """
+         Invokes [action] function on each element of the given Sequence in parallel.
+
+         Example 1:
+        >>> lst = ['a', 'b', 'c']
+        >>> it(lst).parallel_foreach(lambda x: print(x))
+        a
+        b
+        c
+        """
+        self.parallel_on_each(action)
     
     def foreach_indexed(self, action: Callable[[T, int], None]) -> None:
         """
@@ -1218,8 +1249,54 @@ class Sequence(Generic[T], Iterable[T]):
         b 1
         c 2
         """
+        self.on_each_indexed(action)
+    
+    def on_each(self, action: Callable[[T], None]) -> Sequence[T]:
+        """
+         Invokes [action] function on each element of the given Sequence.
+
+         Example 1:
+        >>> lst = ['a', 'b', 'c']
+        >>> it(lst).on_each(lambda x: print(x)) and None
+        a
+        b
+        c
+        """
+        for i in self:
+            action(i)
+        return self
+    
+    def parallel_on_each(self, action: Callable[[T], None]) -> Sequence[T]:
+        """
+         Invokes [action] function on each element of the given Sequence.
+
+         Example 1:
+        >>> lst = ['a', 'b', 'c']
+        >>> it(lst).parallel_on_each(lambda x: print(x)) and None
+        a
+        b
+        c
+        """
+        from concurrent.futures import ThreadPoolExecutor
+        with ThreadPoolExecutor() as executor:
+            for i in self:
+                executor.submit(action, i)
+        return self
+    
+    def on_each_indexed(self, action: Callable[[T, int], None]) -> Sequence[T]:
+        """
+         Invokes [action] function on each element of the given Sequence.
+
+         Example 1:
+        >>> lst = ['a', 'b', 'c']
+        >>> it(lst).on_each_indexed(lambda x, i: print(x, i)) and None
+        a 0
+        b 1
+        c 2
+        """
         for i, e in enumerate(self):
             action(e, i)
+        return self
     
     @overload
     def zip(self, other: Sequence[T]) -> Sequence[Tuple[T, T]]:
@@ -1290,7 +1367,84 @@ class Sequence(Generic[T], Iterable[T]):
         [('a', 'b'), ('a', 'c'), ('b', 'c')]
         """
         return CombinationSequence(self, n)
+    
 
+    def nth(self, n: int) -> T:
+        """
+         Returns the nth element of the given Sequence.
+
+         Example 1:
+        >>> lst = ['a', 'b', 'c']
+        >>> it(lst).nth(2)
+        'c'
+        """
+        return self.skip(n).first( )
+    
+
+    def windowed(self, size: int, step: int = 1, partialWindows: bool = False) -> Sequence[Sequence[T]]:
+        """
+         Returns a Sequence of all possible sliding windows of size [size] from the given Sequence.
+
+         Example 1:
+        >>> lst = ['a', 'b', 'c', 'd', 'e']
+        >>> it(lst).windowed(3)
+        [['a', 'b', 'c'], ['b', 'c', 'd'], ['c', 'd', 'e']]
+
+         Example 2:
+        >>> lst = ['a', 'b', 'c', 'd', 'e']
+        >>> it(lst).windowed(3, 2)
+        [['a', 'b', 'c'], ['c', 'd', 'e']]
+
+         Example 3:
+        >>> lst = ['a', 'b', 'c', 'd', 'e', 'f']
+        >>> it(lst).windowed(3, 2, True)
+        [['a', 'b', 'c'], ['c', 'd', 'e'], ['e', 'f']]
+        """
+        return WindowedSequence(self, size, step, partialWindows)
+    
+
+    def chunked(self, size: int) -> Sequence[Sequence[T]]:
+        """
+         Returns a Sequence of all possible chunks of size [size] from the given Sequence.
+
+         Example 1:
+        >>> lst = ['a', 'b', 'c', 'd', 'e']
+        >>> it(lst).chunked(3)
+        [['a', 'b', 'c'], ['d', 'e']]
+        """
+        return self.windowed(size, size, True)
+
+    
+    def concat(self, *other: Sequence[T]) -> Sequence[T]:
+        """
+         Returns a Sequence of all elements of the given Sequence, followed by all elements of the given Sequence.
+
+         Example 1:
+        >>> lst1 = ['a', 'b', 'c']
+        >>> lst2 = [1, 2, 3]
+        >>> it(lst1).concat(lst2)
+        ['a', 'b', 'c', 1, 2, 3]
+
+         Example 2:
+        >>> lst1 = ['a', 'b', 'c']
+        >>> lst2 = [1, 2, 3]
+        >>> lst3 = [4, 5, 6]
+        >>> it(lst1).concat(lst2, lst3)
+        ['a', 'b', 'c', 1, 2, 3, 4, 5, 6]
+        """
+        return ConcatSequence([self, *other])
+    
+
+    def join(self, separator: str = ' ') -> str:
+        """
+         Joins the elements of the given Sequence into a string.
+
+         Example 1:
+        >>> lst = ['a', 'b', 'c']
+        >>> it(lst).join(', ')
+        'a, b, c'
+        """
+        return separator.join(self)
 
     def to_set(self) -> Set[T]:
         """
@@ -1507,52 +1661,136 @@ class CombinationSequence(Sequence[Tuple[T, ...]]):
         yield from combinations(self._iter, self._n)
 
 
+class WindowedSequence(Sequence[List[T]]):
+    def __init__(self, iterable: Iterable[T], size: int, step: int, partialWindows :bool) -> None:
+        self._iter = iterable
+        self._size = size
+        self._step = step
+        self._partialWindows = partialWindows
+    
+    def __iter__(self) -> Iterator[List[T]]:
+        from collections import deque
+        window = deque(maxlen=self._size)
+        for e in self._iter:
+            window.append(e)
+            if len(window) == self._size:
+                yield list(window)
+            if len(window) == self._size:
+                for _ in range(self._step):
+                    window.popleft()
+        
+        if self._partialWindows:
+            yield list(window)
+
+
+class ConcatSequence(Sequence[T]):
+    def __init__(self, iterable: Iterable[Iterable[T]]) -> None:
+        self._iter = iterable
+    
+    def __iter__(self) -> Iterator[T]:
+        for i in self._iter:
+            yield from i
+
+
+
 def throw(exception: Exception) -> None:
     raise exception
 
 
-def sequence(iterable: Iterable[T]) -> Sequence[T]:
+@overload
+def sequence(*elements: T) -> Sequence[T]:
     """
-     Returns a Sequence with elements of the given Iterable.
-
+     Creates an iterator from a list of elements or given Iterable.
+    
      Example 1:
-    >>> seq(['a', 'b', 'c'])
-    ['a', 'b', 'c']
+    >>> sequence('hello', 'world').map(lambda x: x.upper())
+    ['HELLO', 'WORLD']
+
+     Example 2:
+    >>> sequence(['hello', 'world']).map(lambda x: x.upper())
+    ['HELLO', 'WORLD']
+
+     Example 3:
+    >>> sequence(range(10)).map(lambda x: x*x)
+    [0, 1, 4, 9, 16, 25, 36, 49, 64, 81]
     """
+    ...
+@overload
+def sequence(elements: Iterable[T]) -> Sequence[T]:
+    ...
+def sequence(*iterable: Iterable[T]) -> Sequence[T]:
+    """
+     Creates an iterator from a list of elements or given Iterable.
+    
+     Example 1:
+    >>> sequence('hello', 'world').map(lambda x: x.upper())
+    ['HELLO', 'WORLD']
+
+     Example 2:
+    >>> sequence(['hello', 'world']).map(lambda x: x.upper())
+    ['HELLO', 'WORLD']
+
+     Example 3:
+    >>> sequence(range(10)).map(lambda x: x*x)
+    [0, 1, 4, 9, 16, 25, 36, 49, 64, 81]
+    """
+    if len(iterable) == 1 and isinstance(iterable[0], Iterable):
+        return Sequence(iterable[0])
     return Sequence(iterable)
 
 
-def seq(iterable: Iterable[T]) -> Sequence[T]:
-    """
-     Returns a Sequence with elements of the given Iterable.
+seq = sequence
+"""
+    Creates an iterator from a list of elements or given Iterable.
 
-     Example 1:
-    >>> it(['a', 'b', 'c'])
-    ['a', 'b', 'c']
-    """
-    return sequence(iterable)
+    Example 1:
+>>> seq('hello', 'world').map(lambda x: x.upper())
+['HELLO', 'WORLD']
+
+    Example 2:
+>>> seq(['hello', 'world']).map(lambda x: x.upper())
+['HELLO', 'WORLD']
+
+    Example 3:
+>>> seq(range(10)).map(lambda x: x*x)
+[0, 1, 4, 9, 16, 25, 36, 49, 64, 81]
+"""
 
 
-def iterate(iterable: Iterable[T]) -> Sequence[T]:
-    """
-     Returns a Sequence with elements of the given Iterable.
+iterate = sequence
+"""
+    Creates an iterator from a list of elements or given Iterable.
 
-     Example 1:
-    >>> it(['a', 'b', 'c'])
-    ['a', 'b', 'c']
-    """
-    return sequence(iterable)
+    Example 1:
+>>> iterate('hello', 'world').map(lambda x: x.upper())
+['HELLO', 'WORLD']
+
+    Example 2:
+>>> iterate(['hello', 'world']).map(lambda x: x.upper())
+['HELLO', 'WORLD']
+
+    Example 3:
+>>> iterate(range(10)).map(lambda x: x*x)
+[0, 1, 4, 9, 16, 25, 36, 49, 64, 81]
+"""
 
 
-def it(iterable: Iterable[T]) -> Sequence[T]:
-    """
-     Returns a Sequence with elements of the given Iterable.
+it = sequence
+"""
+    Creates an iterator from a list of elements or given Iterable.
 
-     Example 1:
-    >>> it(['a', 'b', 'c'])
-    ['a', 'b', 'c']
-    """
-    return sequence(iterable)
+    Example 1:
+>>> it('hello', 'world').map(lambda x: x.upper())
+['HELLO', 'WORLD']
+
+    Example 2:
+>>> it(['hello', 'world']).map(lambda x: x.upper())
+['HELLO', 'WORLD']
+
+    Example 3:
+>>> it(range(10)).map(lambda x: x*x)
+[0, 1, 4, 9, 16, 25, 36, 49, 64, 81]
+"""
 
 
 if __name__ == "__main__":
